check_graphab_version: Check whether the Graphab project has been created with...

View source: R/check_graphab_version.R

check_graphab_versionR Documentation

Check whether the Graphab project has been created with graphab.jar >= 3.0

Description

The function checks whether the Graphab project has been created with graphab.jar >= 3.0

Usage

check_graphab_version(proj_path)

Arguments

proj_path

The path to the project .xml file.

Value

If the version is < graphab-3.0.jar, the function returns a message specifying that the project has been created with an earlier version and that this version of graph4lg should not be used, or that another project should be created.

Author(s)

P. Savary

Examples

## Not run: 
proj_end_path <- "./graphab_example/graphab_example.xml"
check_graphab_version(proj_path = proj_end_path)

## End(Not run)

graph4lg documentation built on Sept. 24, 2026, 5:12 p.m.