The function returns a data.frame with the cost values corresponding
to every raster code value.
Arguments
proj_name
A character string indicating the Graphab project name.
The project name is also the name of the project directory in which the
file proj_name.xml has been created.
linkset
A character string indicating the name of the link set used
to create the graph. Link sets can be created with graphab_link.
proj_path
(optional) A character string indicating the path to the
directory that contains the project directory. It should be used when the
project directory is not in the current working directory. Default is NULL.
When 'proj_path = NULL', the project directory is equal to getwd().