powered by
The function computes Gini coefficient from a numeric vector
gini_coeff(x, unbiased = TRUE)
A numeric vector with positive values
A logical value indicating whether the computed coefficient is biased or not. Unbiased value are equal to n/(n-1) times the biased ones.
A numeric value corresponding to the Gini coefficient of the numeric vector
# NOT RUN { x <- c(10, 2, 5, 15) gini <- gini_coeff(x) # }
Run the code above in your browser using DataLab