graphab_merge_graph: Merge graphs in a multiple-graph Graphab project

View source: R/graphab_merge_graph.R

graphab_merge_graphR Documentation

Merge graphs in a multiple-graph Graphab project

Description

The function creates one graph from several other graphs

Usage

graphab_merge_graph(
  proj_name,
  graphs,
  name = NULL,
  proj_path = NULL,
  parallel.java = NULL,
  alloc_ram = NULL
)

Arguments

proj_name

A character string indicating the Graphab project name. The project name is also the name of the project directory in which the file proj_name.xml is. It can be created with graphab_project

graphs

A character vector indicating the names of the graphs to be merged. These graphs must already exist in the project. Graphs can be created with graphab_graph.

name

A character string indicating the name of the graph created by merging the other graphs.

proj_path

(optional) A character string indicating the path to the directory that contains the project directory. It should be used when the project directory is not in the current working directory. Default is NULL. When 'proj_path = NULL', the project directory is equal to getwd().

parallel.java

An integer indicating how many computer cores are used to run the .jar file. By default, parallel.java = NULL, and java sets it according to local settings.

alloc_ram

(optional, default = NULL) Integer or numeric value indicating RAM gigabytes allocated to the java process. Increasing this value can speed up the computations. Too large values may not be compatible with your machine settings.

Details

By default, intra-patch distances are considered for metric calculation. See more information in Graphab 3.0 manual: https://thema.umlp.fr/productions/software/graphab/download/manual-3.0-en.pdf

Author(s)

P. Savary

Examples

## Not run: 
graphab_merge_graph(proj_name = "graphab_example",
              graphs = c("graph_forest_1", "graph_shrub_2"),
              name = "g_all")

## End(Not run)

graph4lg documentation built on Sept. 24, 2026, 5:12 p.m.