Learn R Programming

graph4lg (version 2.0.0)

graphab_pointset: Add a point set to the Graphab project

Description

The function adds a spatial point set to the Graphab project. These points will define a new habitat type with 0-capacity at first.

Usage

graphab_pointset(
  proj_name,
  linkset = NULL,
  name,
  pointset,
  id = NULL,
  return_val = NULL,
  proj_path = NULL,
  parallel.java = NULL,
  alloc_ram = NULL
)

Arguments

proj_name

A character string indicating the Graphab project name. The project name is also the name of the project directory in which the file proj_name.xml is.

linkset

Deprecated parameter from graph4lg < 2.0

name

A character string indicating the name of the new habitat type created by adding this point set to the project.

pointset

Can be either:

  • A character string indicating the path (absolute or relative) to a geopackage point layer with its extension (.gpkg).

  • A character string indicating the path to a .csv file with three columns: ID, x and y, respectively indicating the point ID, longitude and latitude.

  • A data.frame with three columns: ID, x and y, respectively indicating the point ID, longitude and latitude.

id

Deprecated parameter from graph4lg < 2.0

return_val

Deprecated parameter from graph4lg < 2.0

proj_path

(optional) A character string indicating the path to the directory that contains the project directory. It should be used when the project directory is not in the current working directory. Default is NULL. When 'proj_path = NULL', the project directory is equal to getwd().

parallel.java

An integer indicating how many computer cores are used to run the .jar file. By default, parallel.java = NULL, and java sets it according to local settings.

alloc_ram

(optional, default = NULL) Integer or numeric value indicating RAM gigabytes allocated to the java process. Increasing this value can speed up the computations. Too large values may not be compatible with your machine settings.

Author

P. Savary

Details

Point coordinates must be in the same coordinate reference system as the habitat patches (and initial raster layer). See more information in Graphab 3.0 manual: https://thema.umlp.fr/productions/software/graphab/download/manual-3.0-en.pdf

References

foltete2012softwaregraph4lg foltete2021graphabgraph4lg savary2024multiplegraph4lg

Examples

Run this code
if (FALSE) {
graphab_pointset(proj_name = "graphab_example",
                 name = "pts_pop",
                 pointset = "pts_pop.gpkg")
}

Run the code above in your browser using DataLab