graphab_show: Show the objects created in the Graphab project

View source: R/graphab_show.R

graphab_showR Documentation

Show the objects created in the Graphab project

Description

The function lists the objects created in the project.

Usage

graphab_show(proj_path)

Arguments

proj_path

The path to the project .xml file.

Details

Given that this function calls Java and is heavier than other check-ups, functions reading the .xml file are usually preferred.

Value

The list of objects

A list of the existing objects, with NULL values if none exists.

Author(s)

P. Savary

Examples

## Not run: 
proj_end_path <- "./graphab_example/graphab_example.xml"
graphab_show(proj_path = proj_end_path)

## End(Not run)

graph4lg documentation built on Sept. 24, 2026, 5:12 p.m.