Learn R Programming

graph4lg (version 1.6.0)

harm_mean: Compute the harmonic mean of a numeric vector

Description

The function computes the harmonic mean of a numeric vector

Usage

harm_mean(x)

Arguments

x

A numeric vector

Value

A numeric value corresponding to the harmonic mean of the vector

Examples

Run this code
# NOT RUN {
x <- c(10, 2, 5, 15)
hm <- harm_mean(x)
# }

Run the code above in your browser using DataLab