Learn R Programming

graph4lg (version 2.0.0)

check_graphab_object: Check whether a Graphab object exists in the Graphab project.

Description

The function checks whether a given object exists in the Graphab project. This can be a habitat, a linkset or a graph.

Usage

check_graphab_object(proj_path, object_type, name)

Value

A logical specifying whether the object exists.

Arguments

proj_path

The path to the project .xml file.

object_type

A character string with the name of the object type whose list will be checked. Can be either "habitat", "linkset", or "graph".

name

A character string (or vector) with the name(s) of the object(s) whose existence is checked.

Author

P. Savary

Examples

Run this code
if (FALSE) {
proj_end_path <- "./graphab_example/graphab_example.xml"
check_graphab_object(proj_path = proj_end_path,
                     object_type = "habitat",
                     name = "forest")
}

Run the code above in your browser using DataLab