View source: R/check_graphab_version.R
| check_graphab_version | R Documentation |
The function checks whether the Graphab project has been created with graphab.jar >= 3.0
check_graphab_version(proj_path)
proj_path |
The path to the project .xml file. |
If the version is < graphab-3.0.jar, the function returns a message specifying that the project has been created with an earlier version and that this version of graph4lg should not be used, or that another project should be created.
P. Savary
## Not run:
proj_end_path <- "./graphab_example/graphab_example.xml"
check_graphab_version(proj_path = proj_end_path)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.