check_graphab_version: Check whether the Graphab project has been created with graphab.jar >= 3.0
Description
The function checks whether the Graphab project has been
created with graphab.jar >= 3.0
Usage
check_graphab_version(proj_path)
Value
If the version is < graphab-3.0.jar, the function returns a
message specifying that the project has been created with an earlier
version and that this version of graph4lg should not be used, or that
another project should be created.