A character string indicating the Graphab project name.
The project name is also the name of the project directory in which the
file proj_name.xml is. It can be created with graphab_project
graphs
A character vector indicating the names of the graphs to be
merged. These graphs must already exist in the project. Graphs can be
created with graphab_graph.
name
A character string indicating the name of the graph created
by merging the other graphs.
proj_path
(optional) A character string indicating the path to the
directory that contains the project directory. It should be used when the
project directory is not in the current working directory. Default is NULL.
When 'proj_path = NULL', the project directory is equal to getwd().
parallel.java
An integer indicating how many computer cores are used
to run the .jar file. By default, parallel.java = NULL, and java sets
it according to local settings.
alloc_ram
(optional, default = NULL) Integer or numeric value
indicating RAM gigabytes allocated to the java process. Increasing this
value can speed up the computations. Too large values may not be compatible
with your machine settings.