Learn R Programming

graph4lg (version 2.0.0)

graphab_project_desc: Describe the objects of a Graphab project

Description

The function describes the objects of a Graphab project

Usage

graphab_project_desc(proj_name, proj_path = NULL)

Value

It returns a large list describing the objects in several categories, including:

  • Source raster: the values of the source raster file.

  • Habitats: the list of created habitats, their code, their name, their type (raster, vector), and, if raster, their code in the raster.

  • Linksets: the list of created linksets and their type. If computed in cost distance units, a table of costs or the name of the external cost raster file is returned.

  • Graphs: the list of graphs that have been created.

  • Metrics: the list of computed metrics and their associated graphs.

Arguments

proj_name

A character string indicating the Graphab project name. The project name is also the name of the project directory in which the file proj_name.xml has been created.

proj_path

(optional) A character string indicating the path to the directory that contains the project directory. It should be used when the project directory is not in the current working directory. Default is NULL. When 'proj_path = NULL', the project directory is equal to getwd().

Author

P. Savary

Examples

Run this code
if (FALSE) {
graphab_project_desc(proj_name = "graphab_example")
}

Run the code above in your browser using DataLab