Source raster: the values of the source raster file.
Habitats: the list of created habitats, their code, their name,
their type (raster, vector), and, if raster, their code in the raster.
Linksets: the list of created linksets and their type. If computed
in cost distance units, a table of costs or the name of the external cost
raster file is returned.
Graphs: the list of graphs that have been created.
Metrics: the list of computed metrics and their associated graphs.