| graphab_show | R Documentation |
The function lists the objects created in the project.
graphab_show(proj_path)
proj_path |
The path to the project .xml file. |
Given that this function calls Java and is heavier than other check-ups, functions reading the .xml file are usually preferred.
The list of objects
A list of the existing objects, with NULL values if none exists.
P. Savary
## Not run:
proj_end_path <- "./graphab_example/graphab_example.xml"
graphab_show(proj_path = proj_end_path)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.