Learn R Programming

graph4lg (version 2.0.0)

graphab_show: Show the objects created in the Graphab project

Description

The function lists the objects created in the project.

Usage

graphab_show(proj_path)

Value

The list of objects

A list of the existing objects, with NULL values if none exists.

Arguments

proj_path

The path to the project .xml file.

Author

P. Savary

Details

Given that this function calls Java and is heavier than other check-ups, functions reading the .xml file are usually preferred.

Examples

Run this code
if (FALSE) {
proj_end_path <- "./graphab_example/graphab_example.xml"
graphab_show(proj_path = proj_end_path)
}

Run the code above in your browser using DataLab