powered by
The function lists the objects created in the project.
graphab_show(proj_path)
The list of objects
A list of the existing objects, with NULL values if none exists.
The path to the project .xml file.
P. Savary
Given that this function calls Java and is heavier than other check-ups, functions reading the .xml file are usually preferred.
if (FALSE) { proj_end_path <- "./graphab_example/graphab_example.xml" graphab_show(proj_path = proj_end_path) }
Run the code above in your browser using DataLab