powered by
The function computes the harmonic mean of a numeric vector
harm_mean(x)
A numeric vector
A numeric value corresponding to the harmonic mean of the vector
# NOT RUN { x <- c(10, 2, 5, 15) hm <- harm_mean(x) # }
Run the code above in your browser using DataLab